summaryrefslogtreecommitdiff
path: root/plugins/TwitterBridge
diff options
context:
space:
mode:
authorSiebrand Mazeland <s.mazeland@xs4all.nl>2009-11-08 23:22:38 +0100
committerSiebrand Mazeland <s.mazeland@xs4all.nl>2009-11-08 23:22:38 +0100
commit0ab17f382b9993ada3d12d4cdace72cca53fb545 (patch)
treeea8d1923f5ceb2a797e6b6962f74ae33367cf891 /plugins/TwitterBridge
parent221b779e88e51b70a2c3509798154c461203e636 (diff)
* [Cc]an't -> [Cc]annot
* [Cc]ould't -> [Cc]ould not
Diffstat (limited to 'plugins/TwitterBridge')
-rwxr-xr-xplugins/TwitterBridge/daemons/synctwitterfriends.php8
-rwxr-xr-xplugins/TwitterBridge/daemons/twitterstatusfetcher.php8
2 files changed, 8 insertions, 8 deletions
diff --git a/plugins/TwitterBridge/daemons/synctwitterfriends.php b/plugins/TwitterBridge/daemons/synctwitterfriends.php
index 671e3c7af..6a155b301 100755
--- a/plugins/TwitterBridge/daemons/synctwitterfriends.php
+++ b/plugins/TwitterBridge/daemons/synctwitterfriends.php
@@ -126,7 +126,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
$conn->disconnect();
// XXX: Couldn't find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
@@ -188,7 +188,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
if (empty($more_friends)) {
common_log(LOG_WARNING, $this->name() .
- " - Couldn't retrieve page $i " .
+ " - Could not retrieve page $i " .
"of Twitter user $flink->foreign_id friends.");
continue;
} else {
@@ -222,11 +222,11 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
if (!save_twitter_user($friend_id, $friend_name)) {
common_log(LOG_WARNING, $this-name() .
- " - Couldn't save $screen_name's friend, $friend_name.");
+ " - Could not save $screen_name's friend, $friend_name.");
continue;
}
- // Check to see if there's a related local user
+ // Check to see if there is a related local user
$friend_flink = Foreign_link::getByForeignID($friend_id,
TWITTER_SERVICE);
@@ -126,7 +126,7 @@ class SyncTwitterFriendsDaemon extends ParallelizingDaemon
$conn->disconnect();
- // XXX: Couldn't find a less brutal way to blow
+ // XXX: Could not find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
diff --git a/plugins/TwitterBridge/daemons/twitterstatusfetcher.php b/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
index b5428316b..ab610e553 100755
--- a/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
+++ b/plugins/TwitterBridge/daemons/twitterstatusfetcher.php
@@ -147,7 +147,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$conn->disconnect();
// XXX: Couldn't find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;
@@ -158,7 +158,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
{
if (empty($flink)) {
common_log(LOG_WARNING, $this->name() .
- " - Can't retrieve Foreign_link for foreign ID $fid");
+ " - Cannot retrieve Foreign_link for foreign ID $fid");
return;
}
@@ -458,7 +458,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$profile = Profile::staticGet($profile_id);
if (empty($profile)) {
- common_debug($this->name() . " - Couldn't get profile: $profile_id!");
+ common_debug($this->name() . " - Could not get profile: $profile_id!");
return;
}
@@ -537,7 +537,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$ok = file_put_contents($avatarfile, $response->getBody());
if (!$ok) {
common_log(LOG_WARNING, $this->name() .
- " - Couldn't open file $filename");
+ " - Could not open file $filename");
return false;
}
} else {
@@ -147,7 +147,7 @@ class TwitterStatusFetcher extends ParallelizingDaemon
$conn->disconnect();
- // XXX: Couldn't find a less brutal way to blow
+ // XXX: Could not find a less brutal way to blow
// away a cached connection
global $_DB_DATAOBJECT;